@@ -7,15 +7,39 @@ from .form import FormMixin
 from .model import ModelMixin
 
 
+def log_insert(user, flag, message, obj=None, dt=None):
+    from django.contrib.admin.models import ADDITION, CHANGE, DELETION
+    flags = dict(
+        create=ADDITION,
+        update=CHANGE,
+        delete=DELETION
+    )
+    flag = flags.get(flag, flag)
+    logentry = LogEntry(
+        user_id=user.pk,
+        action_flag=flag,
+        change_message=message,
+    )
+    if obj:
+        logentry.content_type_id = ContentType.objects.get_for_model(obj).pk
+        logentry.object_id = obj.pk
+        logentry.object_repr = str(obj)[:200]
+    if dt:
+        logentry.action_time = dt
+    logentry.save()
+    return logentry
+
+
 class ModelFormMixin(ModelMixin, FormMixin):
     """ModelForm Mixin using readable"""
     menus = ['model']
 
     def get_form_kwargs(self):
         self.form_kwargs = super().get_form_kwargs()
-        if (hasattr(self, 'object')
-                and issubclass(self.form_class, model_forms.ModelForm)):
-
+        if (
+            hasattr(self, 'object')
+            and issubclass(self.form_class, model_forms.ModelForm)
+        ):
             self.form_kwargs.update({'instance': self.object})
         return self.form_kwargs
 
@@ -28,14 +52,17 @@ class ModelFormMixin(ModelMixin, FormMixin):
     def get_form_base(self):
         return None
 
-    def get_form_class(self):
+    def get_modelform_kwargs(self):
         kwargs = dict()
         if self.form_base:
             kwargs['form'] = self.form_base
+        kwargs['fields'] = self.form_fields
+        return kwargs
+
+    def get_form_class(self):
         return model_forms.modelform_factory(
             self.model,
-            fields=self.form_fields,
-            **kwargs
+            **self.modelform_kwargs
         )
 
     def get_form_invalid_message(self):
@@ -86,17 +113,17 @@ class ModelFormMixin(ModelMixin, FormMixin):
 
         if hasattr(self, 'object_list'):
             objects = self.object_list
+        elif hasattr(self, 'log_objects'):
+            objects = self.log_objects
         else:
             objects = [self.object]
 
         for obj in objects:
-            LogEntry.objects.log_action(
-                self.request.user.pk,
-                ContentType.objects.get_for_model(self.model).pk,
-                obj.pk,
-                str(obj),
+            log_insert(
+                self.request.user,
                 self.log_action_flag,
                 self.log_message,
+                obj,
             )
 
     def form_valid(self):
