@@ -28,7 +28,7 @@ class JinjaColumn(tables.Column):
                 object=record
             )
         )
-        b = template.engines['backend']
+        b = template.engines['crudlfap']
         t = b.from_string(self.template_code)
         r = t.render(context)
         return mark_safe(r)
@@ -86,6 +86,7 @@ class TableMixin(object):
                     'row-actions-' + str(object.pk),
                     class='btn-floating red',
                     next=request.path_info,
+                    icon='more_vert',
                 ) }}
                 ''',
                 verbose_name=_('Actions'),
@@ -188,7 +189,7 @@ class TableMixin(object):
         )
 
     def get_table_kwargs(self):
-        return {}
+        return dict(data=self.object_list)
 
     def get_table_pagination(self):
         if not self.paginate_by:
@@ -197,7 +198,6 @@ class TableMixin(object):
 
     def get_table(self):
         kwargs = self.table_kwargs
-        kwargs.update(data=self.object_list)
         self.table = self.build_table_class()(**kwargs)
         RequestConfig(
             self.request,
