@@ -212,6 +212,7 @@ TEMPLATE_CONSTANTS = {
 CRUDLFAP_TEMPLATE_BACKEND = {
     "BACKEND": "django_jinja.backend.Jinja2",
     "APP_DIRS": True,
+    "NAME": "crudlfap",
     "OPTIONS": {
         "app_dirname": "jinja2",
         "match_extension": None,
@@ -246,6 +247,7 @@ CRUDLFAP_TEMPLATE_BACKEND = {
             "type": type,
             "render_form": "crudlfap.jinja2.render_form",
             "render_button": "bootstrap3.forms.render_button",
+            "url": "django.urls.reverse",
         },
         "newstyle_gettext": True,
         "bytecode_cache": {
